@@ -14,12 +14,16 @@
 #' @author Joshua French
 #' @export
 print.kdenv = function(x, ..., extra = FALSE) {
-  cat("Difference in K functions\n")
+  cat("\nEnvelopes for difference in estimated K functions\n\n")
+  cat("KD(r) = K_case(r) - K_control(r)\n")
   cat("case label: ", x$case_label, "\n")
   cat("control label: ", x$control_label, "\n")
+  cat("KD(r) computed for r betwen ",
+      x$rlim[1], "and", x$rlim[2], "\n")
   if (x$nsim > 0) {
     cat("number of simulations: ", x$nsim, "\n")
-    cat("level: ", x$level, "\n")
+    cat("simulation procedure: random labeling\n")
+    cat("envelope level: ", x$level, "\n")
   }
   if (extra) {
     x$out  
